@@ -20,7 +20,7 @@ REPO_MAINTAINERS = [
 ]
 
 # Package version in the format (major, minor, release)
-PACKAGE_VERSION_TUPLE = (0, 14, 2)
+PACKAGE_VERSION_TUPLE = (0, 14, 3)
 
 # Short description of the package
 PACKAGE_SHORT_DESCRIPTION = "A composable, maintainable system for managing templates"
@@ -72,7 +72,7 @@ PACKAGE_INSTALL_REQUIRES = [
     "rich",
     "markupsafe<2.1",
     # Need to land support for Copier 6.0.0, until then peg to 5 or below
-    "copier<6",
+    "copier==5.*",
 ]
 
 # Add any third party packages you use in requirements for optional features of your package here
